pub fn slice_as_bytes_mut<T>(buf: &mut [T]) -> &mut [u8] ⓘExpand description
Reinterpret a mutable slice of any type as a &mut [u8].
SAFETY: same as slice_as_bytes, but with an exclusive &mut borrow.
pub fn slice_as_bytes_mut<T>(buf: &mut [T]) -> &mut [u8] ⓘReinterpret a mutable slice of any type as a &mut [u8].
SAFETY: same as slice_as_bytes, but with an exclusive &mut borrow.